@@ -1,16 +1,17 @@
 import json
+from operator import itemgetter
 
 from pkg_resources import resource_filename
 
 FILENAMES = {
-    "core": "iso-639-3.tab",
-    "pt2": "ISO-639-2_utf-8.txt",
-    "pt5": "iso639-5.tsv",
-    "macro": "iso-639-3-macrolanguages.tab",
-    "mapping": "iso-639.json",
-    "mapping_macro": "iso-639_macro.json",
-    "deprecated": "iso-639-3_Retirements.tab",
-    "mapping_deprecated": "iso-639_deprecated.json",
+    "core": "data/iso-639-3.tab",
+    "pt2": "data/ISO-639-2_utf-8.txt",
+    "pt5": "data/iso639-5.tsv",
+    "macro": "data/iso-639-3-macrolanguages.tab",
+    "deprecated": "data/iso-639-3_Retirements.tab",
+    "mapping": "data/iso-639.json",
+    "mapping_macro": "data/iso-639_macro.json",
+    "mapping_deprecated": "data/iso-639_deprecated.json",
 }
 TAGS = ("pt1", "pt2b", "pt2t", "pt3", "pt5", "name")
 
@@ -229,23 +230,35 @@ class DeprecatedMapping:
     @classmethod
     def _build(cls):
 
-        mapping = {}
         with open(cls._fps["deprecated"], encoding="utf-8") as f:
-            next(f)
-            for line in f:
-                row = line.rstrip().split("\t")
-                mapping[row[0]] = {
-                    k: row[i + 1]
-                    for i, k in enumerate(
-                        [
-                            "ref_name",
-                            "ret_reason",
-                            "change_to",
-                            "ret_remedy",
-                            "effective",
-                        ]
-                    )
-                }
+            rows = [line.rstrip().split("\t") for line in f]
+
+        # make sure that deprecations are ordered chronologically
+        sorted_deprecated = sorted(rows[1:], key=itemgetter(-1))
+
+        mapping = {}
+        for (
+            pt3,
+            ref_name,
+            ret_reason,
+            change_to,
+            ret_remedy,
+            effective,
+        ) in sorted_deprecated:
+            if change_to == pt3:  # avoid infinite loops to self
+                continue
+            # when a deprecation routes to an already deprecated
+            # lang, the older one is canceled
+            if change_to in mapping:
+                del mapping[change_to]
+
+            mapping[pt3] = {
+                "ref_name": ref_name,
+                "ret_reason": ret_reason,
+                "change_to": change_to,
+                "ret_remedy": ret_remedy,
+                "effective": effective,
+            }
 
         return mapping
 
